@@ -73,8 +73,8 @@ test_that("invalid `baseline` fails", {
 })
 
 test_that(paste(
-  "`object` of class \"vsel\" (created by varsel()), `nterms_max`, `stats`,",
-  "and `type` work"
+  "`object` of class `vsel` (created by varsel()) and arguments `nterms_max`,",
+  "`stats`, and `type` work"
 ), {
   skip_if_not(run_vs)
   for (tstsetup in names(smmrys_vs)) {
@@ -91,14 +91,14 @@ test_that(paste(
       stats_expected = args_smmry_vs[[tstsetup]]$stats,
       type_expected = args_smmry_vs[[tstsetup]]$type,
       nterms_max_expected = args_smmry_vs[[tstsetup]]$nterms_max,
-      solterms_expected = vss[[tstsetup_vs]]$solution_terms
+      prd_trms_expected = vss[[tstsetup_vs]]$predictor_ranking
     )
   }
 })
 
 test_that(paste(
-  "`object` of class \"vsel\" (created by cv_varsel()), `nterms_max`, `stats`,",
-  "and `type` work"
+  "`object` of class `vsel` (created by cv_varsel()) and arguments",
+  "`nterms_max`, `stats`, and `type` work"
 ), {
   skip_if_not(run_cvvs)
   for (tstsetup in names(smmrys_cvvs)) {
@@ -117,25 +117,83 @@ test_that(paste(
       nterms_max_expected = args_smmry_cvvs[[tstsetup]]$nterms_max,
       cv_method_expected =
         args_cvvs[[tstsetup_cvvs]]$cv_method %||% "LOO",
-      solterms_expected = cvvss[[tstsetup_cvvs]]$solution_terms
+      prd_trms_expected = cvvss[[tstsetup_cvvs]]$predictor_ranking
     )
   }
 })
 
+# performances() ----------------------------------------------------------
+
+context("performances()")
+
+test_that("`object` of class `vsel` (created by varsel()) works", {
+  skip_if_not(run_vs)
+  for (tstsetup in names(perfs_vs)) {
+    tstsetup_smmry_vs <- args_perf_vs[[tstsetup]]$tstsetup_smmry_vsel
+    performances_tester(
+      perfs_vs[[tstsetup]],
+      smmry_expected = smmrys_vs[[tstsetup_smmry_vs]],
+      info_str = tstsetup
+    )
+  }
+})
+
+test_that("`object` of class `vsel` (created by cv_varsel()) works", {
+  skip_if_not(run_cvvs)
+  for (tstsetup in names(perfs_cvvs)) {
+    tstsetup_smmry_cvvs <- args_perf_cvvs[[tstsetup]]$tstsetup_smmry_vsel
+    performances_tester(
+      perfs_cvvs[[tstsetup]],
+      smmry_expected = smmrys_cvvs[[tstsetup_smmry_cvvs]],
+      info_str = tstsetup
+    )
+  }
+})
+
+test_that("performances.vsel() is a shortcut", {
+  skip_if_not(run_vs)
+  skip_if_not(run_cvvs)
+  for (tstsetup in names(smmrys_vs)) {
+    args_smmry_i <- args_smmry_vs[[tstsetup]]
+    if (any(c("rmse", "auc") %in% args_smmry_i$stats)) {
+      smmry_seed <- list(seed = seed3_tst)
+    } else {
+      smmry_seed <- list()
+    }
+    perf_from_vsel <- do.call(performances, c(
+      list(object = vss[[args_smmry_i$tstsetup_vsel]]),
+      excl_nonargs(args_smmry_i),
+      smmry_seed
+    ))
+    expect_identical(perf_from_vsel, perfs_vs[[tstsetup]], info = tstsetup)
+  }
+  for (tstsetup in names(smmrys_cvvs)) {
+    args_smmry_i <- args_smmry_cvvs[[tstsetup]]
+    if (any(c("rmse", "auc") %in% args_smmry_i$stats)) {
+      smmry_seed <- list(seed = seed3_tst)
+    } else {
+      smmry_seed <- list()
+    }
+    perf_from_vsel <- do.call(performances, c(
+      list(object = cvvss[[args_smmry_i$tstsetup_vsel]]),
+      excl_nonargs(args_smmry_i),
+      smmry_seed
+    ))
+    expect_identical(perf_from_vsel, perfs_cvvs[[tstsetup]], info = tstsetup)
+  }
+})
+
 # print() -----------------------------------------------------------------
 
 context("print()")
 
-test_that("`x` of class \"vselsummary\" (based on varsel()) works", {
+test_that("`x` of class `vselsummary` (based on varsel()) works", {
   skip_if_not(run_vs)
   for (tstsetup in names(smmrys_vs)) {
-    expect_message(
-      expect_output(
-        print_obj <- print(smmrys_vs[[tstsetup]]),
-        "Family:.*Link function:.*Formula:.*Observations:",
-        info = tstsetup
-      ),
-      NA
+    expect_output(
+      print_obj <- print(smmrys_vs[[tstsetup]]),
+      "Family:.*Link function:.*Formula:.*Observations:",
+      info = tstsetup
     )
     expect_identical(print_obj, smmrys_vs[[tstsetup]], info = tstsetup)
     if (run_snaps) {
@@ -151,22 +209,14 @@ test_that("`x` of class \"vselsummary\" (based on varsel()) works", {
   }
 })
 
-test_that("`x` of class \"vselsummary\" (based on cv_varsel())  works", {
+test_that("`x` of class `vselsummary` (based on cv_varsel())  works", {
   skip_if_not(run_cvvs)
   for (tstsetup in names(smmrys_cvvs)) {
     args_crr <- args_cvvs[[args_smmry_cvvs[[tstsetup]]$tstsetup_vsel]]
-    if (isFALSE(args_crr$validate_search)) {
-      mssg_expected <- NA
-    } else {
-      mssg_expected <- "Column.*contains the full-data predictor ranking"
-    }
-    expect_message(
-      expect_output(
-        print_obj <- print(smmrys_cvvs[[tstsetup]]),
-        "Family:.*Link function:.*Formula:.*Observations:",
-        info = tstsetup
-      ),
-      mssg_expected
+    expect_output(
+      print_obj <- print(smmrys_cvvs[[tstsetup]]),
+      "Family:.*Link function:.*Formula:.*Observations:",
+      info = tstsetup
     )
     expect_identical(print_obj, smmrys_cvvs[[tstsetup]], info = tstsetup)
     if (run_snaps) {
@@ -183,7 +233,7 @@ test_that("`x` of class \"vselsummary\" (based on cv_varsel())  works", {
 })
 
 test_that(paste(
-  "`x` of class \"vsel\" (created by varsel()) and passing arguments to",
+  "`x` of class `vsel` (created by varsel()) and passing arguments to",
   "summary.vsel() works"
 ), {
   skip_if_not(run_vs)
@@ -208,7 +258,7 @@ test_that(paste(
 })
 
 test_that(paste(
-  "`x` of class \"vsel\" (created by cv_varsel()) and passing arguments to",
+  "`x` of class `vsel` (created by cv_varsel()) and passing arguments to",
   "summary.vsel() works"
 ), {
   skip_if_not(run_cvvs)
@@ -236,21 +286,56 @@ test_that(paste(
 
 context("plot()")
 
-test_that("`x` of class \"vsel\" (created by varsel()) works", {
+test_that("`x` of class `vsel` (created by varsel()) works", {
   skip_if_not(run_vs)
-  common_elements <- c("tstsetup_vsel", "nterms_max", "ranking_nterms_max",
-                       "text_angle")
+  common_for_rk_NA <- c("tstsetup_vsel", "text_angle", "nterms_max",
+                        "ranking_nterms_max")
+  common_for_rk_max <- c("tstsetup_vsel", "text_angle", "nterms_max",
+                         "ranking_abbreviate", "ranking_repel")
   for (tstsetup in names(plots_vs)) {
     args_plot_i <- args_plot_vs[[tstsetup]]
     if (identical(args_plot_i$ranking_nterms_max, NA)) {
       matches_tstsetup <- sapply(names(plots_vs), function(tstsetup2) {
-        common_elements <- intersect(common_elements, names(args_plot_i))
+        common_for_rk_NA <- intersect(common_for_rk_NA, names(args_plot_i))
         args_plot_i2 <- args_plot_vs[[tstsetup2]]
-        common_elements2 <- intersect(common_elements, names(args_plot_i2))
-        if (!setequal(common_elements, common_elements2)) {
+        common_for_rk_NA2 <- intersect(common_for_rk_NA, names(args_plot_i2))
+        if (!setequal(common_for_rk_NA, common_for_rk_NA2)) {
           return(FALSE)
         }
-        identical(args_plot_i[common_elements], args_plot_i2[common_elements])
+        identical(args_plot_i[common_for_rk_NA], args_plot_i2[common_for_rk_NA])
+      })
+      if (any(matches_tstsetup)) {
+        tstsetup_target <- names(which.max(matches_tstsetup))
+      } else {
+        tstsetup_target <- tstsetup
+      }
+    } else if (length(args_plot_i$ranking_nterms_max) &&
+               identical(args_plot_i$ranking_nterms_max,
+                         args_plot_i$nterms_max)) {
+      matches_tstsetup <- sapply(names(plots_vs), function(tstsetup2) {
+        common_for_rk_max <- intersect(common_for_rk_max, names(args_plot_i))
+        args_plot_i2 <- args_plot_vs[[tstsetup2]]
+        common_for_rk_max2 <- intersect(common_for_rk_max, names(args_plot_i2))
+        if (!setequal(common_for_rk_max, common_for_rk_max2)) {
+          return(FALSE)
+        }
+        identical(args_plot_i[common_for_rk_max],
+                  args_plot_i2[common_for_rk_max])
+      })
+      if (any(matches_tstsetup)) {
+        tstsetup_target <- names(which.max(matches_tstsetup))
+      } else {
+        tstsetup_target <- tstsetup
+      }
+    } else if (args_plot_i$ranking_colored || args_plot_i$cumulate) {
+      not_common_here <- c("ranking_colored", "cumulate")
+      matches_tstsetup <- sapply(names(plots_vs), function(tstsetup2) {
+        args_plot_i2 <- args_plot_vs[[tstsetup2]]
+        if (!setequal(names(args_plot_i), names(args_plot_i2))) {
+          return(FALSE)
+        }
+        identical(args_plot_i[setdiff(names(args_plot_i), not_common_here)],
+                  args_plot_i2[setdiff(names(args_plot_i2), not_common_here)])
       })
       if (any(matches_tstsetup)) {
         tstsetup_target <- names(which.max(matches_tstsetup))
@@ -273,21 +358,42 @@ test_that("`x` of class \"vsel\" (created by varsel()) works", {
   }
 })
 
-test_that("`x` of class \"vsel\" (created by cv_varsel()) works", {
+test_that("`x` of class `vsel` (created by cv_varsel()) works", {
   skip_if_not(run_cvvs)
-  common_elements <- c("tstsetup_vsel", "nterms_max", "ranking_nterms_max",
-                       "text_angle")
+  common_for_rk_NA <- c("tstsetup_vsel", "text_angle", "nterms_max",
+                        "ranking_nterms_max")
+  common_for_rk_max <- c("tstsetup_vsel", "text_angle", "nterms_max",
+                         "ranking_abbreviate", "ranking_repel",
+                         "ranking_colored", "cumulate")
   for (tstsetup in names(plots_cvvs)) {
     args_plot_i <- args_plot_cvvs[[tstsetup]]
     if (identical(args_plot_i$ranking_nterms_max, NA)) {
       matches_tstsetup <- sapply(names(plots_cvvs), function(tstsetup2) {
-        common_elements <- intersect(common_elements, names(args_plot_i))
+        common_for_rk_NA <- intersect(common_for_rk_NA, names(args_plot_i))
         args_plot_i2 <- args_plot_cvvs[[tstsetup2]]
-        common_elements2 <- intersect(common_elements, names(args_plot_i2))
-        if (!setequal(common_elements, common_elements2)) {
+        common_for_rk_NA2 <- intersect(common_for_rk_NA, names(args_plot_i2))
+        if (!setequal(common_for_rk_NA, common_for_rk_NA2)) {
           return(FALSE)
         }
-        identical(args_plot_i[common_elements], args_plot_i2[common_elements])
+        identical(args_plot_i[common_for_rk_NA], args_plot_i2[common_for_rk_NA])
+      })
+      if (any(matches_tstsetup)) {
+        tstsetup_target <- names(which.max(matches_tstsetup))
+      } else {
+        tstsetup_target <- tstsetup
+      }
+    } else if (length(args_plot_i$ranking_nterms_max) &&
+               identical(args_plot_i$ranking_nterms_max,
+                         args_plot_i$nterms_max)) {
+      matches_tstsetup <- sapply(names(plots_cvvs), function(tstsetup2) {
+        common_for_rk_max <- intersect(common_for_rk_max, names(args_plot_i))
+        args_plot_i2 <- args_plot_cvvs[[tstsetup2]]
+        common_for_rk_max2 <- intersect(common_for_rk_max, names(args_plot_i2))
+        if (!setequal(common_for_rk_max, common_for_rk_max2)) {
+          return(FALSE)
+        }
+        identical(args_plot_i[common_for_rk_max],
+                  args_plot_i2[common_for_rk_max])
       })
       if (any(matches_tstsetup)) {
         tstsetup_target <- names(which.max(matches_tstsetup))
@@ -337,8 +443,8 @@ test_that(paste(
 ), {
   skip_if_not(run_vs)
   tstsetups <- grep(paste("\\.default_nterms_max_smmry", "\\.default_rk_max",
-                          "\\.default_abbv", "\\.default_repel", "\\.cuFALSE",
-                          "\\.default_angle", sep = ".*"),
+                          "\\.default_abbv", "\\.default_repel", "\\.colFALSE",
+                          "\\.cuFALSE", "\\.default_angle", sep = ".*"),
                     names(plots_vs), value = TRUE)
   for (tstsetup in tstsetups) {
     args_plot_i <- args_plot_vs[[tstsetup]]
@@ -362,8 +468,8 @@ test_that(paste(
 ), {
   skip_if_not(run_cvvs)
   tstsetups <- grep(paste("\\.default_nterms_max_smmry", "\\.default_rk_max",
-                          "\\.default_abbv", "\\.default_repel", "\\.cuFALSE",
-                          "\\.default_angle", sep = ".*"),
+                          "\\.default_abbv", "\\.default_repel", "\\.colFALSE",
+                          "\\.cuFALSE", "\\.default_angle", sep = ".*"),
                     names(plots_cvvs), value = TRUE)
   for (tstsetup in tstsetups) {
     args_plot_i <- args_plot_cvvs[[tstsetup]]
@@ -459,7 +565,7 @@ test_that("`object` of class `vsel` (created by varsel()) works", {
     nterms_max_expected_crr <- args_rk_vs[[tstsetup]][["nterms_max"]]
     ranking_tester(
       rks_vs[[tstsetup]],
-      fulldata_expected = vss[[tstsetup_vs]][["solution_terms"]],
+      fulldata_expected = vss[[tstsetup_vs]][["predictor_ranking"]],
       foldwise_expected = NULL,
       nterms_max_expected = nterms_max_expected_crr,
       info_str = tstsetup
@@ -474,8 +580,8 @@ test_that("`object` of class `vsel` (created by cv_varsel()) works", {
     nterms_max_expected_crr <- args_rk_cvvs[[tstsetup]][["nterms_max"]]
     ranking_tester(
       rks_cvvs[[tstsetup]],
-      fulldata_expected = cvvss[[tstsetup_cvvs]][["solution_terms"]],
-      foldwise_expected = cvvss[[tstsetup_cvvs]][["solution_terms_cv"]],
+      fulldata_expected = cvvss[[tstsetup_cvvs]][["predictor_ranking"]],
+      foldwise_expected = cvvss[[tstsetup_cvvs]][["predictor_ranking_cv"]],
       nterms_max_expected = nterms_max_expected_crr,
       info_str = tstsetup
     )
@@ -507,7 +613,7 @@ test_that(paste(
       prs_cvvs[[tstsetup]],
       cumulate_expected = args_pr_cvvs[[tstsetup]][["cumulate"]],
       nterms_max_expected = nterms_max_expected_crr,
-      cnms_expected = cvvss[[tstsetup_cvvs]][["solution_terms"]],
+      cnms_expected = cvvss[[tstsetup_cvvs]][["predictor_ranking"]],
       info_str = tstsetup
     )
   }
@@ -553,12 +659,13 @@ test_that("`cumulate = TRUE` works", {
 
 test_that("ranking proportions are computed correctly", {
   skip_on_cran()
+  tol_abs <- sqrt(.Machine$double.eps)
   # With `cumulate = FALSE`:
   cv_proportions_tester(pr_cF, nterms_max_expected = ntrms,
                         cnms_expected = rk_fdata, info_str = "cumulate = FALSE")
-  expect_true(all(pr_cF == 1 / ntrms), info = "cumulate = FALSE")
-  expect_true(all(rowSums(pr_cF) == 1), info = "cumulate = FALSE")
-  expect_true(all(colSums(pr_cF) == 1), info = "cumulate = FALSE")
+  expect_true(all(abs(pr_cF - 1 / ntrms) < tol_abs), info = "cumulate = FALSE")
+  expect_true(all(abs(rowSums(pr_cF) - 1) < tol_abs), info = "cumulate = FALSE")
+  expect_true(all(abs(colSums(pr_cF) - 1) < tol_abs), info = "cumulate = FALSE")
 
   # With `cumulate = TRUE`:
   cv_proportions_tester(pr_cT, cumulate_expected = TRUE,
@@ -568,7 +675,9 @@ test_that("ranking proportions are computed correctly", {
   class(pr_cT_expected) <- c("cv_proportions_cumul", "cv_proportions")
   expect_equal(pr_cT, pr_cT_expected, check.attributes = FALSE,
                tolerance = .Machine$double.eps, info = "cumulate = TRUE")
-  has_1_colwise <- all(apply(pr_cT, 2, function(x_col) 1 %in% x_col))
+  has_1_colwise <- all(apply(pr_cT, 2, function(x_col) {
+    any(abs(x_col - 1) < tol_abs)
+  }))
   expect_true(has_1_colwise, info = "cumulate = TRUE")
 })
 
